% make coral manuscript figures
% - fig. 1. x-ray ptychographic linear dichroism (on/pre-edge)
% - fig. S1. x-ray ptychographic linear dichroism (on/pre-edge)
% taken from make_xas_spectrum_fig.m

%% display BG corrected and aligned ptychography (rPIE) output images
load('/Users/yuanhunglo/Documents/Miao_Group/synchrotron_ALS/coral/ptychography_data/rpie_results_processed.mat');
stp = @(x,y,z) subtightplot(x, y, z, [0.01 .01]);

im1_pre = [];
im2_pre = [];
im3_pre = [];
im1_on = [];
im2_on = [];
im3_on = [];

c = 1;
crop_sz = [180 180];

for n = 1:12
    im_pre = rpie.pre_imgs_corrected{n};
    im_on = rpie.on_imgs_corrected{n};
    
    if n <= 4 % dragon head
        imstack_on_fig1(:,:,n) = rpie.on_imgs_corrected{n};
        imstack_pre_fig1(:,:,n) = rpie.pre_imgs_corrected{n};
        
        im1_pre = cat(1, im1_pre, im_pre);
        im1_on = cat(1, im1_on, im_on);
    elseif n >= 5 && n <= 8 % blob
        im2_pre = cat(1, im2_pre, rot90(im_pre));
        im2_on = cat(1, im2_on, rot90(im_on));
    elseif n > 8 % peanut
        im3_pre = cat(1, im3_pre, im_pre);
        im3_on = cat(1, im3_on, im_on);
    end
end

im1_pre = circshift(im1_pre, [10 0]);
im1_on = circshift(im1_on, [10 0]);

%% shift dragon head images down a bit
im_montage_pre = cat(2, im1_pre, im2_pre, im3_pre);
im_montage_on = cat(2, im1_on, im2_on, im3_on);

cmap = colormap(gray);
pixel_size = 10.1; % nm

% cmap = flipud(cmap);

%%% display montage
%%% pre-edge absroption (beta)
figure(20); set(gcf, 'colormap', cmap, 'color', 'w', 'position', [100    67   521   565])
    %%% add scale bar
    bar_size = 500; % nm
    bar_len_px = ceil(bar_size/pixel_size);
    im_montage_pre(172:177, 15:15+bar_len_px) = max(real(im_montage_pre(:)))*.7;
    
    imagesc(real(im_montage_pre)); axis image off 
%     title('Absorption (beta), pre-edge')
    caxis([1*min(real(im_montage_pre(:))) .7*max(real(im_montage_pre(:)))])
    cbar = colorbar('southoutside');
    cbar.Label.String = 'Absorption';
    cbar.Position = [0.2214    0.06    0.5932    0.04];  
    T=text(14, 160, '500 nm'); set(T, 'color', 'w')
    
%%% pre-edge phase (delta)
figure(21); set(gcf, 'colormap', cmap, 'color', 'w', 'position', [300    67   521   565])
    imagesc(imag(im_montage_pre)); axis image off
%     title('Phase (delta), pre-edge')
    caxis([1*min(imag(im_montage_pre(:))) .75*max(imag(im_montage_pre(:)))])
    cbar = colorbar('southoutside');
    cbar.Label.String = 'Phase';
    cbar.Position = [0.2214    0.06    0.5932    0.04];  
    
%%% on-edge absorption (beta)
figure(22); set(gcf, 'colormap', cmap, 'color', 'w', 'position', [500 67   521   565])
    %%% add scale bar
    bar_size = 500; % nm
    bar_len_px = ceil(bar_size/pixel_size);
    im_montage_on(172:177, 15:15+bar_len_px) = max(real(im_montage_on(:)))*.7;
    
    imagesc(real(im_montage_on)); axis image off 
%     title('Absorption (beta), on-edge')
    caxis([1*min(real(im_montage_on(:))) .7*max(real(im_montage_on(:)))])
    cbar = colorbar('southoutside');
    cbar.Label.String = 'Absorption';
    cbar.Position = [0.2214    0.06    0.5932    0.04];  
    T=text(14, 160, '500 nm'); set(T, 'color', 'w')

%%% on-edge phase (delta)
figure(23); set(gcf, 'colormap', cmap, 'color', 'w', 'position', [700    67   521   565])
    imagesc(imag(im_montage_on)); axis image off
%     title('Phase (delta), on-edge')
    caxis([1*min(imag(im_montage_on(:))) .75*max(imag(im_montage_on(:)))])
    cbar = colorbar('southoutside');
    cbar.Label.String = 'Phase';
    cbar.Position = [0.2214    0.06    0.5932    0.04];  
    
%% save images
outdir = '/Users/yuanhunglo/Dropbox/Miao_Group/manuscripts/ALS_coral/figures/fig2/';
if 1
    figure(20); export_fig([outdir 'absor_pre_edge.pdf'])
    figure(21); export_fig([outdir 'phase_pre_edge.pdf'])
    figure(22); export_fig([outdir 'absor_on_edge.pdf'])
    figure(23); export_fig([outdir 'phase_on_edge.pdf'])
end

%% make image stack of dragon head for Fig. 1 schematics
figure(24); set(gcf, 'colormap', cmap, 'color', 'w', 'position', [68   815   311   290])
for n = 1:4
    imagesc(real(imstack_on_fig1(:,:,n))); axis image off
    fname = sprintf('/Users/yuanhunglo/Dropbox/Miao_Group/manuscripts/ALS_coral/figures/fig1/peanut/peanut_on_abs_%d.pdf', n);
    export_fig(fname)
    
    imagesc(imag(imstack_pre_fig1(:,:,n))); axis image off
    fname = sprintf('/Users/yuanhunglo/Dropbox/Miao_Group/manuscripts/ALS_coral/figures/fig1/peanut/peanut_pre_phs_%d.pdf', n);
    export_fig(fname)
end
